@@ -1,4 +1,4 @@
 from .__version__ import __version__  # noqa: F401
 
-from . import datasets  # noqa: F401
+from . import data  # noqa: F401
 from . import vignettes  # noqa: F401
